@@ -138,6 +138,19 @@ Roadmap :
 ◦ Fix icon in package
 ◦ Fix help windows title
 
+• Version 3.0.8 :
+◦ Fix syntax error
+
+• Version 3.0.9 :
+◦ Keep last opened folder when opening or saving file instead of going to MyDocs folder by default
+◦ Remove saveas menu from welcome screen
+◦ Fix Bug #8837
+◦ Add errors message when not able to open or decode file
+◦ Fix apply prefs for lines numbers
+◦ Fix recent file change in main
+◦ Fix back to begin search when there is 2 results only
+◦ Fix order of recent files
+
 •Version 3.3.0 :
 ◦ Plugins
 ◦ Snippet
