@@ -72,24 +72,55 @@ class Window(hildon.Window):
     hbox.add(open_button)
     vbox.add(hbox)
 
-    r = gtk.RecentManager().get_items()
-    if (len(r)>0):
+    self.recent_manager = gtk.recent_manager_get_default()
+#    self.recent_manager.set_limit(3)
+    self.recent_manager.connect('changed',self.recent_manager_changed)
+    ritems=self.recent_manager.get_items()
+    ritems.sort(lambda x,y: y.get_modified()-x.get_modified())
+
+    if (len(ritems)>2):
       vbox.add(gtk.Label('Recent Files'))        
-
-      for index,item in enumerate(r):
-        if index>2:
-          break
-        b=hildon.Button(0,1)
-        label = item.get_uri_display()
-        b.set_title(os.path.basename(label))
-        b.set_value(label)
-        b.set_alignment(0.0,0.0,0.0,0.5)
-        vbox.add(b)
-        b.connect("clicked", self.recent_button_clicked, label)
-
+      self.recent_button_1=hildon.Button(0,1)
+      label = ritems[0].get_uri_display()
+      self.recent_button_1.set_title(os.path.basename(label))
+      self.recent_button_1.set_value(label)
+      self.recent_button_1.set_alignment(0.0,0.0,0.0,0.5)
+      vbox.add(self.recent_button_1)
+      self.recent_button_1.connect("clicked", self.recent_button_clicked, label)
+      self.recent_button_2=hildon.Button(0,1)
+      label = ritems[1].get_uri_display()
+      self.recent_button_2.set_title(os.path.basename(label))
+      self.recent_button_2.set_value(label)
+      self.recent_button_2.set_alignment(0.0,0.0,0.0,0.5)
+      vbox.add(self.recent_button_2)
+      self.recent_button_2.connect("clicked", self.recent_button_clicked, label)
+      self.recent_button_3=hildon.Button(0,1)
+      label = ritems[2].get_uri_display()
+      self.recent_button_3.set_title(os.path.basename(label))
+      self.recent_button_3.set_value(label)
+      self.recent_button_3.set_alignment(0.0,0.0,0.0,0.5)
+      vbox.add(self.recent_button_3)
+      self.recent_button_3.connect("clicked", self.recent_button_clicked, label)
+      
     return p1
     
+  def recent_manager_changed(self,widget,*data):
+    ritems=self.recent_manager.get_items()
+    ritems.sort(lambda x,y: y.get_modified()-x.get_modified())
+    if (len(ritems)>2):
+      label = ritems[0].get_uri_display()
+      self.recent_button_1.set_title(os.path.basename(label))
+      self.recent_button_1.set_value(label)
+      label = ritems[1].get_uri_display()
+      self.recent_button_2.set_title(os.path.basename(label))
+      self.recent_button_2.set_value(label)
+      label = ritems[2].get_uri_display()
+      self.recent_button_3.set_title(os.path.basename(label))
+      self.recent_button_3.set_value(label)
+      
+    
   def recent_button_clicked(self,button,url):
+    url = button.get_value()
     self._parent.create_window(url)
     
   def menu_button_clicked(self,button, label):
@@ -138,10 +169,10 @@ class Window(hildon.Window):
     self.recent_menu_button.set_label(label)                             
     self.recent_menu_button.connect("clicked", self.menu_button_clicked, label)
     menu.append(self.recent_menu_button)                                 
-    label = 'Save as'
-    self.saveas_menu_button.set_label(label)
-    self.saveas_menu_button.connect("clicked", self.menu_button_clicked, label)
-    menu.append(self.saveas_menu_button)
+#    label = 'Save as'
+#    self.saveas_menu_button.set_label(label)
+#    self.saveas_menu_button.connect("clicked", self.menu_button_clicked, label)
+#    menu.append(self.saveas_menu_button)
     self.about_menu_button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
     label = 'About'
     self.about_menu_button.set_label(label)
@@ -163,10 +194,11 @@ class Window(hildon.Window):
   def open_dialog(self,*data):
       fc = gobject.new(hildon.FileChooserDialog, action=gtk.FILE_CHOOSER_ACTION_OPEN)
       fc.set_property('show-files',True)
-      fc.set_current_folder('/home/user/MyDocs/')
+      fc.set_current_folder(self._parent._last_opened_folder)
       if fc.run()==gtk.RESPONSE_OK:
         filepath = fc.get_filename()
         fc.destroy()
+        self._parent._last_opened_folder = os.path.dirname(filepath)      
         self._parent.create_window(filepath)
       else:
         fc.destroy()
