@@ -152,11 +152,13 @@ class Window(hildon.Window):
     if self.prefs.prefs_dict['show_lines'] == True:
       self.code_editor.set_border_window_size(gtk.TEXT_WINDOW_LEFT, 30)
       self.code_editor.line_view = self.code_editor.get_window(gtk.TEXT_WINDOW_LEFT)
-      self.code_editor.connect("expose_event", self.code_editor.line_numbers_expose)
+      if self.code_editor.expose_event_cb==None:
+        self.code_editor.expose_even_cb = self.code_editor.connect("expose_event", self.code_editor.line_numbers_expose)
     else:
       self.code_editor.set_border_window_size(gtk.TEXT_WINDOW_LEFT, 0)
 #      self.code_editor.line_view = None
-      self.code_editor.disconnect("expose_event")
+      if self.code_editor.expose_event_cb!=None:
+        self.code_editor.disconnect(self.code_editor.expose_event_cb)
   
   def onHideFind(self, widget):
     self.findToolBar.hide()
